[Bf-blender-cvs] [2ff2900f7fa] master: Cleanup: use return argument prefix

Campbell Barton noreply at git.blender.org
Sun Feb 14 02:20:39 CET 2021


Commit: 2ff2900f7fa65110222544a5e14fac9876058ad6
Author: Campbell Barton
Date:   Sun Feb 14 11:38:04 2021 +1100
Branches: master
https://developer.blender.org/rB2ff2900f7fa65110222544a5e14fac9876058ad6

Cleanup: use return argument prefix

===================================================================

M	source/blender/editors/space_action/action_edit.c
M	source/blender/editors/space_nla/nla_edit.c

===================================================================

diff --git a/source/blender/editors/space_action/action_edit.c b/source/blender/editors/space_action/action_edit.c
index f8389d40831..5c061518570 100644
--- a/source/blender/editors/space_action/action_edit.c
+++ b/source/blender/editors/space_action/action_edit.c
@@ -312,11 +312,11 @@ void ACTION_OT_previewrange_set(wmOperatorType *ot)
 /**
  * Find the extents of the active channel
  *
  * \param[out] min: Bottom y-extent of channel
  * \param[out] max: Top y-extent of channel
  * \return Success of finding a selected channel
  */
-static bool actkeys_channels_get_selected_extents(bAnimContext *ac, float *min, float *max)
+static bool actkeys_channels_get_selected_extents(bAnimContext *ac, float *r_min, float *r_max)
 {
   ListBase anim_data = {NULL, NULL};
   bAnimListElem *ale;
@@ -339,8 +339,8 @@ static bool actkeys_channels_get_selected_extents(bAnimContext *ac, float *min,
     if (acf && acf->has_setting(ac, ale, ACHANNEL_SETTING_SELECT) &&
         ANIM_channel_setting_get(ac, ale, ACHANNEL_SETTING_SELECT)) {
       /* update best estimate */
-      *min = ymax - ACHANNEL_HEIGHT(ac);
-      *max = ymax;
+      *r_min = ymax - ACHANNEL_HEIGHT(ac);
+      *r_max = ymax;
 
       /* is this high enough priority yet? */
       found = acf->channel_role;
@@ -312,11 +312,11 @@ void ACTION_OT_previewrange_set(wmOperatorType *ot)
  * Find the extents of the active channel
  *
- * \param[out] min: Bottom y-extent of channel
- * \param[out] max: Top y-extent of channel
- * \return Success of finding a selected channel
+ * \param r_min: Bottom y-extent of channel.
+ * \param r_max: Top y-extent of channel.
+ * \return Success of finding a selected channel.
  */
diff --git a/source/blender/editors/space_nla/nla_edit.c b/source/blender/editors/space_nla/nla_edit.c
index 893d2c0e2c8..7bfb753474d 100644
--- a/source/blender/editors/space_nla/nla_edit.c
+++ b/source/blender/editors/space_nla/nla_edit.c
@@ -406,11 +406,11 @@ void NLA_OT_previewrange_set(wmOperatorType *ot)
 /**
  * Find the extents of the active channel
  *
  * \param[out] min: Bottom y-extent of channel.
  * \param[out] max: Top y-extent of channel.
  * \return Success of finding a selected channel
  */
-static bool nla_channels_get_selected_extents(bAnimContext *ac, float *min, float *max)
+static bool nla_channels_get_selected_extents(bAnimContext *ac, float *r_min, float *r_max)
 {
   ListBase anim_data = {NULL, NULL};
   bAnimListElem *ale;
@@ -434,8 +434,8 @@ static bool nla_channels_get_selected_extents(bAnimContext *ac, float *min, floa
     if (acf && acf->has_setting(ac, ale, ACHANNEL_SETTING_SELECT) &&
         ANIM_channel_setting_get(ac, ale, ACHANNEL_SETTING_SELECT)) {
       /* update best estimate */
-      *min = ymax - NLACHANNEL_HEIGHT(snla);
-      *max = ymax;
+      *r_min = ymax - NLACHANNEL_HEIGHT(snla);
+      *r_max = ymax;
 
       /* is this high enough priority yet? */
       found = acf->channel_role;
@@ -406,11 +406,11 @@ void NLA_OT_previewrange_set(wmOperatorType *ot)
  * Find the extents of the active channel
  *
- * \param[out] min: Bottom y-extent of channel.
- * \param[out] max: Top y-extent of channel.
- * \return Success of finding a selected channel
+ * \param r_min: Bottom y-extent of channel.
+ * \param r_max: Top y-extent of channel.
+ * \return Success of finding a selected channel.
  */



More information about the Bf-blender-cvs mailing list